@@ -236,16 +236,19 @@ protected:
     QString                  m_newerVersionIs;
 
     struct LayerConfiguration {
-	LayerConfiguration(LayerFactory::LayerType _layer
-			                       = LayerFactory::TimeRuler,
+        LayerConfiguration(LayerFactory::LayerType _layer
+                                               = LayerFactory::TimeRuler,
                            Model *_source = 0,
                            int _channel = -1) :
-	    layer(_layer), sourceModel(_source), channel(_channel) { }
-	LayerFactory::LayerType layer;
+            layer(_layer), sourceModel(_source), channel(_channel) { }
+        LayerFactory::LayerType layer;
         Model *sourceModel;
-	int channel;
+        int channel;
     };
 
+    QString shortcutFor(LayerFactory::LayerType, bool isPaneMenu);
+    void updateLayerShortcutsFor(Model *);
+    
     typedef std::map<QAction *, LayerConfiguration> PaneActionMap;
     PaneActionMap m_paneActions;
 
